summaryrefslogtreecommitdiffstats
path: root/quanta/parts/kafka/undoredo.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'quanta/parts/kafka/undoredo.cpp')
-rw-r--r--quanta/parts/kafka/undoredo.cpp26
1 files changed, 13 insertions, 13 deletions
diff --git a/quanta/parts/kafka/undoredo.cpp b/quanta/parts/kafka/undoredo.cpp
index 85f23398..647709b1 100644
--- a/quanta/parts/kafka/undoredo.cpp
+++ b/quanta/parts/kafka/undoredo.cpp
@@ -59,7 +59,7 @@ NodeModif::~NodeModif()
{
if(m_node)
{
- m_node->tqparent = 0L;
+ m_node->parent = 0L;
m_node->next = 0L;
m_node->prev = 0L;
if(m_type == NodeRemoved)
@@ -87,7 +87,7 @@ void NodeModif::setNode(Node *node)
m_node = node;
if(m_node)
{
- m_node->tqparent = 0L;
+ m_node->parent = 0L;
m_node->next = 0L;
m_node->prev = 0L;
if(m_type == NodeRemoved)
@@ -544,14 +544,14 @@ bool undoRedo::undoNodeModif(NodeModif *nodeModif)
node = kafkaCommon::getNodeFromLocation(nodeModif->location());
if(!node)
{
// No node at this location, getting the tqparent Node and appending newNode after
// the last child of the tqparent.
ref = nodeModif->location();
TQValueList<int> loc(ref);
loc.remove(loc.fromLast());
if(loc.empty())
{
// No tqparent, adding it on top of the tree.
kafkaCommon::insertNode(newNode, 0L, 0L, 0L, false);
}
else
@@ -568,7 +568,7 @@ bool undoRedo::undoNodeModif(NodeModif *nodeModif)
else
{
// A node is already here. Moving it to the right and adding newNode here.
- kafkaCommon::insertNode(newNode, node->tqparent, node, 0L, false);
+ kafkaCommon::insertNode(newNode, node->parent, node, 0L, false);
}
}
if(nodeModif->type() == NodeModif::NodeTreeRemoved)
@@ -756,7 +756,7 @@ bool undoRedo::undoNodeModifInKafka(NodeModif */**_nodeModif*/)
while(n->next)
n = n->next;
}
- if(n->tqparent->_leafNode.isNull())
+ if(n->parent->_leafNode.isNull())
{
dm = domNode.nextSibling();
goUp = false;
@@ -771,7 +771,7 @@ bool undoRedo::undoNodeModifInKafka(NodeModif */**_nodeModif*/)
}
else
{
- domNode2 = n->tqparent->_leafNode;
+ domNode2 = n->parent->_leafNode;
while(!domNode.nextSibling().isNull())
{
//try{
@@ -968,15 +968,15 @@ void undoRedo::reloadQuantaEditor(bool force, bool syncQuantaCursor, bool encode
while(node)
{
//kdDebug(25001)<< "CurNode : " << _node->tag->name << " - " << _node->tag->tagStr() << endl;
- if(node->tqparent)
+ if(node->parent)
{
- node->tqparent->tag->beginPos(bLine3, bCol3);
- node->tqparent->tag->endPos(eLine3, eCol3);
+ node->parent->tag->beginPos(bLine3, bCol3);
+ node->parent->tag->endPos(eLine3, eCol3);
}
node->tag->beginPos(bLine2, bCol2);
//if we are in a Script inside a tag e.g. <a href="<? PHP stuff here ?>">, skip it
- if(node->tag->type == Tag::ScriptTag && node->tqparent &&
+ if(node->tag->type == Tag::ScriptTag && node->parent &&
QuantaCommon::isBetween(bLine2, bCol2, bLine3, bCol3, eLine3,eCol3) == 0)
{
goUp = true;
@@ -990,7 +990,7 @@ void undoRedo::reloadQuantaEditor(bool force, bool syncQuantaCursor, bool encode
allText += node->tag->tagStr();
//If a child is a Script inside this Tag e.g. <a href="<? PHP stuff here ?>">, make
//its position fits inside the tqparent
node->tag->beginPos(bLine3, bCol3);
node->tag->endPos(eLine3, eCol3);
child = node->firstChild();
@@ -544,14 +544,14 @@ bool undoRedo::undoNodeModif(NodeModif *nodeModif)
if(!node)
{
- // No node at this location, getting the tqparent Node and appending newNode after
- // the last child of the tqparent.
+ // No node at this location, getting the parent Node and appending newNode after
+ // the last child of the parent.
ref = nodeModif->location();
TQValueList<int> loc(ref);
@@ -544,14 +544,14 @@ bool undoRedo::undoNodeModif(NodeModif *nodeModif)
if(loc.empty())
{
- // No tqparent, adding it on top of the tree.
+ // No parent, adding it on top of the tree.
kafkaCommon::insertNode(newNode, 0L, 0L, 0L, false);
}
@@ -990,7 +990,7 @@ void undoRedo::reloadQuantaEditor(bool force, bool syncQuantaCursor, bool encode
allText += node->tag->tagStr();
//If a child is a Script inside this Tag e.g. <a href="<? PHP stuff here ?>">, make
- //its position fits inside the tqparent
+ //its position fits inside the parent
node->tag->beginPos(bLine3, bCol3);
node->tag->endPos(eLine3, eCol3);